using BPA.SAAS.Manage.Application.Device.Dtos.Device;
using BPA.SAAS.Manage.Core.Base;
using BPA.SAAS.Manage.Core.Device;
using BPA.SAAS.Manage.Core.Product;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BPA.SAAS.Manage.Application.Device.Interface
{
    public interface IProductService
    {
        Task<PageUtil> GetProductPage(ProductQueryInputDto inputDto);
        Task<List<BPA_Product>> GetProductList();
        Task<BPA_Product> GetProduct(string productId);
        Task<bool> AddProduct(ProductBaseDto inputDto);
        Task<bool> DeProduct(List<string> inputList);
        Task<bool> UpdateProduct(ProductBaseDto inputDto);
        Task<bool> UpdateDeviceVesionSatatus(ProductSatatusDto inputDto);
    }
}
